from setuptools import setup

setup(
    name='aritmetica',
    version='0.1',
    packages=['aritmetica'],
    url='https://github.com/marcos-de-sousa',
    license='MIT License',
    author='Marcos Paulo Alves de Sousa',
    author_email='msousa@museu-goeldi.br',
    description='Pacote python para operações aritméticas'
)




def soma(valorx,valory):
    return valorx+valory

def subtracao(valorx,valory):
    return valorx-valory

def multiplicacao(valorx,valory):
    return valorx*valory

def divisao(valorx,valory):
    return valorx/valory